==> haskell-lsp-test0.14.0-0.14.0.2-201-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test0.14.0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-AMDg91SDniOL69wxNh4McZ
key:                  lsp-test-0.14.0.2-AMDg91SDniOL69wxNh4McZ
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  af879251da3a93491213e738645a0be5
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-2bFsfeZQckWA7adjvuwT2E:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-2bFsfeZQckWA7adjvuwT2E:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test0.14.0
hs-libraries:         HSlsp-test-0.14.0.2-AMDg91SDniOL69wxNh4McZ
depends:
    Diff-0.4.1-L8DOUuNGxiiH0X79lq9Zn6
    Glob-0.10.2-12Tvsi3A4nsDSOOvjKvt4o
    aeson-2.1.2.1-Gng3eoGBP2Sj2fbUBsnWH
    aeson-pretty-0.8.10-1UVA7jwF3AY2XeDKFp8bmR
    ansi-terminal-1.0.2-KEBwSt8cOBhArBBqY461TL
    async-2.2.5-6FnQWPoSLF0101MXuyNKqJ base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-CTNxTBwbo3PGCTtXLpLpH4
    conduit-parse-0.2.1.1-BDrTZUqeeTh8klpVQe5r3L containers-0.6.7
    data-default-0.7.1.1-86NXSPgvsmt76HSLrJaFnV directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3-8ZK9QDANmBT9CZTQ77OGiP
    lsp-types-1.4.0.1-2bFsfeZQckWA7adjvuwT2E mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    some-1.0.6-As3QDrvuxaqEQIbQQrudXS text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W

haddock-interfaces:   /usr/share/doc/haskell-lsp-test0.14.0/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test0.14.0/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test0.14.0-0.14.0.2-202-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test0.14.0.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-test
version:              0.14.0.2
visibility:           public
id:                   lsp-test-0.14.0.2-I46r0FJUB7IKvwng08gqIq
key:                  lsp-test-0.14.0.2-I46r0FJUB7IKvwng08gqIq
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  08f445a645a20c552fed4a0f15ee1176
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.4.0.1-x5xQvPudueCzAEdaXc5Ac:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-x5xQvPudueCzAEdaXc5Ac:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-test-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-test0.14.0
hs-libraries:         HSlsp-test-0.14.0.2-I46r0FJUB7IKvwng08gqIq
depends:
    Diff-0.4.1-8NUfR4WKqY5H9Ttf0Koorw
    Glob-0.10.2-CfMdUOLNwWWADTihQDYGgB
    aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn
    aeson-pretty-0.8.10-CwXo2PdeXuRCVi5BLDBjO7
    ansi-terminal-1.0.2-J3CYMek3QCg8mQRiAxriIL
    async-2.2.5-D49NPDHTd69BKX3jfj3d2D base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-8kXjnDSt7SWIbXyadQmMao
    conduit-parse-0.2.1.1-9wCIYw2IrRcCkOkCknR283 containers-0.6.7
    data-default-0.7.1.1-1dWAwpuUe04Bvh1yMI7wxn directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3-4eslcvGQhMj5JgydAUw2Le
    lsp-types-1.4.0.1-x5xQvPudueCzAEdaXc5Ac mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav process-1.6.18.0
    some-1.0.6-C8SVhXoLo1W43DiM5WqKp8 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k

haddock-interfaces:   /usr/share/doc/haskell-lsp-test0.14.0/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test0.14.0/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
